@@ -19,6 +19,7 @@
     GyMMM => "MMM 'de' y G",
     GyMMMEd => "E, d 'de' MMM 'de' y G",
     GyMMMd => "d 'de' MMM 'de' y G",
+    GyMd => "d/M/y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -135,25 +136,25 @@
     "depois de Cristo",
   ],
   first_day_of_week => 1,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
-  glibc_date_format => "%d-%m-%Y",
-  glibc_datetime_format => "%a %d %b %Y %T %Z",
+  glibc_date_1_format => "%a %d %b %Y %T %Z",
+  glibc_date_format => "%d/%m/%Y",
+  glibc_datetime_format => "%a %d %b %Y %T",
   glibc_time_12_format => "%I:%M:%S %p",
   glibc_time_format => "%T",
   language => "Portuguese",
   month_format_abbreviated => [
-    "jan",
-    "fev",
-    "mar",
-    "abr",
-    "mai",
-    "jun",
-    "jul",
-    "ago",
-    "set",
-    "out",
-    "nov",
-    "dez",
+    "jan.",
+    "fev.",
+    "mar.",
+    "abr.",
+    "mai.",
+    "jun.",
+    "jul.",
+    "ago.",
+    "set.",
+    "out.",
+    "nov.",
+    "dez.",
   ],
   month_format_narrow => [
     "J",
@@ -184,18 +185,18 @@
     "dezembro",
   ],
   month_stand_alone_abbreviated => [
-    "jan",
-    "fev",
-    "mar",
-    "abr",
-    "mai",
-    "jun",
-    "jul",
-    "ago",
-    "set",
-    "out",
-    "nov",
-    "dez",
+    "jan.",
+    "fev.",
+    "mar.",
+    "abr.",
+    "mai.",
+    "jun.",
+    "jul.",
+    "ago.",
+    "set.",
+    "out.",
+    "nov.",
+    "dez.",
   ],
   month_stand_alone_narrow => [
     "J",
@@ -274,5 +275,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 35,
+  version => 40,
 }
