@@ -5,44 +5,45 @@
   ],
   available_formats => {
     Bh => "h B",
-    Bhm => "h:mm B",
-    Bhms => "h:mm:ss B",
+    Bhm => "h.mm B",
+    Bhms => "h.mm.ss B",
     E => "ccc",
-    EBhm => "E h:mm B",
-    EBhms => "E h:mm:ss B",
-    EHm => "E HH:mm",
-    EHms => "E HH:mm:ss",
+    EBhm => "E h.mm B",
+    EBhms => "E h.mm.ss B",
+    EHm => "E HH.mm",
+    EHms => "E HH.mm.ss",
     Ed => "E d",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h.mm a",
+    Ehms => "E h.mm.ss a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "y-MM-dd GGGGG",
     H => "HH",
-    Hm => "HH:mm",
-    Hms => "HH:mm:ss",
-    Hmsv => "HH:mm:ss v",
-    Hmv => "HH:mm v",
+    Hm => "HH.mm",
+    Hms => "HH.mm.ss",
+    Hmsv => "HH.mm.ss v",
+    Hmv => "HH.mm v",
     M => "L",
-    MEd => "E d/M",
+    MEd => "E d.M",
     MMM => "LLL",
     MMMEd => "E d MMM",
     MMMMEd => "E d MMMM",
-    "MMMMW-count-one" => "'vecka' W 'i' MMM",
-    "MMMMW-count-other" => "'vecka' W 'i' MMM",
+    "MMMMW-count-one" => "'vecka' W 'i' MMMM",
+    "MMMMW-count-other" => "'vecka' W 'i' MMMM",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
-    MMd => "d/M",
-    MMdd => "dd/MM",
-    Md => "d/M",
+    MMd => "d.M",
+    MMdd => "dd.MM",
+    Md => "d.M",
     d => "d",
     h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
-    ms => "mm:ss",
+    hm => "h.mm a",
+    hms => "h.mm.ss a",
+    hmsv => "h.mm.ss a v",
+    hmv => "h.mm a v",
+    ms => "mm.ss",
     y => "y",
     yM => "y-MM",
     yMEd => "E, y-MM-dd",
@@ -61,7 +62,7 @@
   date_format_full => "EEEE d MMMM y",
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
-  date_format_short => "dd-MM-y",
+  date_format_short => "y-MM-dd",
   datetime_format_full => "{1} {0}",
   datetime_format_long => "{1} {0}",
   datetime_format_medium => "{1} {0}",
@@ -267,10 +268,10 @@
   ],
   script => undef,
   territory => "Finland",
-  time_format_full => "'kl'. HH:mm:ss zzzz",
+  time_format_full => "HH:mm:ss zzzz",
   time_format_long => "HH:mm:ss z",
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 32,
+  version => 40,
 }
